@@ -1,4 +1,4 @@
-/*
+/* -*-mode: C; indent-tabs-mode: t; -*-
  * Copyright (c) 2003 Sun Microsystems, Inc.  All Rights Reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -28,10 +28,6 @@
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
  * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * You acknowledge that this software is not designed or intended for use
- * in the design, construction, operation or maintenance of any nuclear
- * facility.
  */
 
 #include <stdlib.h>
@@ -193,6 +189,7 @@ ipmi_get_channel_info(struct ipmi_intf * intf, uint8_t channel)
 	struct ipmi_rs * rsp;
 	struct ipmi_rq req;
 	uint8_t rqdata[2];
+	uint8_t medium;
 	struct get_channel_info_rsp   channel_info;
 	struct get_channel_access_rsp channel_access;
 
@@ -225,16 +222,16 @@ ipmi_get_channel_info(struct ipmi_intf * intf, uint8_t channel)
 
 	printf("  Session Support       : ");
 	switch (channel_info.session_support) {
-		case 0x00:
+		case 0x0:
 			printf("session-less\n");
 			break;
-		case 0x40:
+		case 0x1:
 			printf("single-session\n");
 			break;
-		case 0x80:
+		case 0x2:
 			printf("multi-session\n");
 			break;
-		case 0xc0:
+		case 0x3:
 		default:
 			printf("session-based\n");
 			break;
@@ -249,6 +246,12 @@ ipmi_get_channel_info(struct ipmi_intf * intf, uint8_t channel)
 		   channel_info.vendor_id[2] << 16);
 
 
+	/* only proceed if this is LAN channel */
+	medium = ipmi_get_channel_medium(intf, channel);
+	if (medium != IPMI_CHANNEL_MEDIUM_LAN &&
+	    medium != IPMI_CHANNEL_MEDIUM_LAN_OTHER) {
+		return 0;
+	}
 
 	memset(&req, 0, sizeof(req));
 	rqdata[0] = channel & 0xf;
@@ -475,6 +478,7 @@ ipmi_set_user_access(struct ipmi_intf * intf, int argc, char ** argv)
 
 	memcpy(&user_access, rsp->data, sizeof(struct get_user_access_rsp));
 
+	memset(&set_access, 0, sizeof(set_access));
 	set_access.change_bits = 1;
 	set_access.callin_callback = user_access.callin_callback;
 	set_access.link_auth = user_access.link_auth;
@@ -544,7 +548,6 @@ iana_string(uint32_t iana)
 
 static int
 ipmi_get_channel_cipher_suites(struct ipmi_intf * intf,
-			       const char * which,
 			       const char * payload_type,
 			       uint8_t channel)
 {
@@ -571,7 +574,7 @@ ipmi_get_channel_cipher_suites(struct ipmi_intf * intf,
 
 	rqdata[0] = channel;
 	rqdata[1] = ((strncmp(payload_type, "ipmi", 4) == 0)? 0: 1);
-	rqdata[2] = ((strncmp(which, "all", 3) == 0)? 0x80: 0);
+	rqdata[2] = 0x80; // Always ask for cipher suite format
 
 	rsp = intf->sendrecv(intf, &req);
 	if (rsp == NULL) {
@@ -744,9 +747,11 @@ ipmi_get_channel_medium(struct ipmi_intf * intf, uint8_t channel)
 		return -1;
 	}
 	if (rsp->ccode > 0) {
-		lprintf(LOG_ERR, "Get Channel Info command failed: %s",
+		if (rsp->ccode == 0xcc)
+			return IPMI_CHANNEL_MEDIUM_RESERVED;
+		lprintf(LOG_INFO, "Get Channel Info command failed: %s",
 		       val2str(rsp->ccode, completion_code_vals));
-		return -1;
+		return IPMI_CHANNEL_MEDIUM_RESERVED;
 	}
 
 	memcpy(&info, rsp->data, sizeof(struct get_channel_info_rsp));
@@ -771,7 +776,7 @@ printf_channel_usage()
 	lprintf(LOG_NOTICE, "                  setaccess <channel number> "
 		"<user id> [callin=on|off] [ipmi=on|off] [link=on|off] [privilege=level]");
 	lprintf(LOG_NOTICE, "                  info      [channel number]");
-	lprintf(LOG_NOTICE, "                  getciphers <all | supported> <ipmi | sol> [channel]\n");
+	lprintf(LOG_NOTICE, "                  getciphers <ipmi | sol> [channel]\n");
 	lprintf(LOG_NOTICE, "Possible privilege levels are:");
 	lprintf(LOG_NOTICE, "   1   Callback level");
 	lprintf(LOG_NOTICE, "   2   User level");
@@ -828,21 +833,19 @@ ipmi_channel_main(struct ipmi_intf * intf, int argc, char ** argv)
 		}
 	}
 
-	// it channel getciphers <all | supported> <ipmi | sol> [channel] 
+	// it channel getciphers <ipmi | sol> [channel] 
 	else if (strncmp(argv[0], "getciphers", 10) == 0)
 	{
-		if ((argc < 3) || (argc > 4)                                         ||
-		    (strncmp(argv[1], "all", 3) && strncmp(argv[1], "supported", 9)) ||
-		    (strncmp(argv[2], "ipmi", 4) && strncmp(argv[2], "sol",  3)))
+		if ((argc < 2) || (argc > 3)  ||
+		    (strncmp(argv[1], "ipmi", 4) && strncmp(argv[1], "sol",  3)))
 			printf_channel_usage();
 		else
 		{
 			uint8_t ch = 0xe;
 			if (argc == 4)
-				ch = (uint8_t)strtol(argv[3], NULL, 0);
+				ch = (uint8_t)strtol(argv[2], NULL, 0);
 			retval = ipmi_get_channel_cipher_suites(intf,
-								argv[1], // all | supported
-								argv[2], // ipmi | sol
+								argv[1], // ipmi | sol
 								ch);
 		}
 	}
