@@ -752,6 +752,7 @@ ipmi_lan_print(struct ipmi_intf * intf, uint8_t chan)
 		return -1;
 	else if (p->data != NULL)
 	{
+		unsigned char cipher_suite_count = p->data[0];
 		p = get_lan_param(intf, chan, IPMI_LANP_RMCP_CIPHERS);
 		if (p == NULL)
 			return -1;
@@ -760,9 +761,8 @@ ipmi_lan_print(struct ipmi_intf * intf, uint8_t chan)
 
 		/* Now we're dangerous.  There are only 15 fixed cipher
 		   suite IDs, but the spec allows for 16 in the return data.*/
-		if ((p->data != NULL) && (p->data_len <= 16))
+		if ((p->data != NULL) && (p->data_len <= 17))
 		{
-			unsigned char cipher_suite_count = p->data[0];
 			unsigned int i;
 			for (i = 0; (i < 16) && (i < cipher_suite_count); ++i)
 			{
@@ -778,7 +778,6 @@ ipmi_lan_print(struct ipmi_intf * intf, uint8_t chan)
 		}
 	}
 
-	
 	/* RMCP+ Messaging Cipher Suite Privilege Levels */
 	/* These are the privilege levels for the 15 fixed cipher suites */
 	p = get_lan_param(intf, chan, IPMI_LANP_RMCP_PRIV_LEVELS);
@@ -2063,63 +2062,59 @@ int
 ipmi_lanp_main(struct ipmi_intf * intf, int argc, char ** argv)
 {
 	int rc = 0;
-   uint8_t chan = 0x0e;
+	uint8_t chan = find_lan_channel(intf, 1);
 
 	if (argc == 0 || (strncmp(argv[0], "help", 4) == 0)) {
 		print_lan_usage();
-      return -1;
+		return -1;
 	}
 
-	if (
-         (strncmp(argv[0], "printconf", 9) == 0) 
-         ||
-	      (strncmp(argv[0], "print", 5) == 0) 
-      )
-   {
+	if (strncmp(argv[0], "printconf", 9) == 0 ||
+	    strncmp(argv[0], "print", 5) == 0)
+	{
 		if (argc > 1)
 			chan = (uint8_t)strtol(argv[1], NULL, 0);
 		if (chan < 1 || chan > IPMI_CHANNEL_NUMBER_MAX)
-      {
-         lprintf(LOG_ERR, "Invalid channel: %d", chan);
+		{
+			lprintf(LOG_ERR, "Invalid channel: %d", chan);
 			return -1;
-       }
+		}
 		else
 			rc = ipmi_lan_print(intf, chan);
 	}
 	else if (strncmp(argv[0], "set", 3) == 0)
 	{
-   	rc = ipmi_lan_set(intf, argc-1, &(argv[1]));
+		rc = ipmi_lan_set(intf, argc-1, &(argv[1]));
 	}
 	else if (strncmp(argv[0], "alert", 5) == 0)
 	{
-   	rc = ipmi_lan_alert(intf, argc-1, &(argv[1]));
-   }
-   else if (strncmp(argv[0], "stats", 5) == 0)
-   {
-      if(argc == 1)
-      {
-   		print_lan_usage();
-			return -1;
-      }
-      else if (argc > 2)
-	   	chan = (uint8_t)strtol(argv[2], NULL, 0);
-         
-   	if (chan < 2 || chan > IPMI_CHANNEL_NUMBER_MAX)
-      {
-         lprintf(LOG_ERR, "Invalid channel: %d", chan);
-			return -1;
-      }
-      else if (strncmp(argv[1], "get", 3) == 0)
-	   	rc = ipmi_lan_stats_get(intf, chan);
-      else if (strncmp(argv[1], "clear", 5) == 0)
-	   	rc = ipmi_lan_stats_clear(intf, chan);
-      else
-   		print_lan_usage();
+		rc = ipmi_lan_alert(intf, argc-1, &(argv[1]));
 	}
-   else
+	else if (strncmp(argv[0], "stats", 5) == 0)
 	{
-   	lprintf(LOG_NOTICE, "Invalid LAN command: %s", argv[0]);
-   }
+		if(argc == 1)
+		{
+			print_lan_usage();
+			return -1;
+		}
+		else if (argc > 2)
+			chan = (uint8_t)strtol(argv[2], NULL, 0);
+         
+		if (chan < 2 || chan > IPMI_CHANNEL_NUMBER_MAX)
+		{
+			lprintf(LOG_ERR, "Invalid channel: %d", chan);
+			return -1;
+		}
+		else if (strncmp(argv[1], "get", 3) == 0)
+			rc = ipmi_lan_stats_get(intf, chan);
+		else if (strncmp(argv[1], "clear", 5) == 0)
+			rc = ipmi_lan_stats_clear(intf, chan);
+		else
+			print_lan_usage();
+	}
+	else
+	{
+		lprintf(LOG_NOTICE, "Invalid LAN command: %s", argv[0]);
+	}
 	return rc;
 }
-
