@@ -26,10 +26,6 @@
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
  * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * You acknowledge that this software is not designed or intended for use
- * in the design, construction, operation or maintenance of any nuclear
- * facility.
  */
 
 #include <string.h>
@@ -39,8 +35,10 @@
 #include <ipmitool/ipmi_constants.h>
 #include <ipmitool/log.h>
 #include <ipmitool/helper.h>
+#include <ipmitool/ipmi_sel.h>
 
 static int ipmi_oem_supermicro(struct ipmi_intf * intf);
+static int ipmi_oem_ibm(struct ipmi_intf * intf);
 
 static struct ipmi_oem_handle ipmi_oem_list[] = {
 	{
@@ -60,6 +58,11 @@ static struct ipmi_oem_handle ipmi_oem_list[] = {
 		name:   "icts",
 		desc:   "IPMI 2.0 ICTS compliance support",
 	},
+	{
+		name:   "ibm",
+		desc:   "IBM OEM support",
+		setup:	ipmi_oem_ibm,
+	},
 	{ 0 },
 };
 
@@ -71,6 +74,17 @@ ipmi_oem_supermicro(struct ipmi_intf * intf)
 	return 0;
 }
 
+static int
+ipmi_oem_ibm(struct ipmi_intf * intf)
+{
+	char * filename;
+	if ((filename = getenv("IPMI_OEM_IBM_DATAFILE")) == NULL) {
+		lprintf(LOG_ERR, "Unable to read IPMI_OEM_IBM_DATAFILE from environment");
+		return -1;
+	}
+	return ipmi_sel_oem_init((const char *)filename);
+}
+
 /* ipmi_oem_print  -  print list of OEM handles
  */
 void
