@@ -28,10 +28,6 @@
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
  * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
  * EVEN IF DELL HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * You acknowledge that this software is not designed or intended for use
- * in the design, construction, operation or maintenance of any nuclear
- * facility.
  */
 
 #include <string.h>
@@ -285,8 +281,8 @@ ipmi_pef_print_lan_dest(struct ipmi_intf * intf, uint8_t ch, uint8_t dest)
 		return;
 	}
 	tbl_size = (rsp->data[1] & PEF_LAN_DEST_TABLE_SIZE_MASK);
-	if (!dest || tbl_size == 0)	/* LAN alerting not supported */
-		return;
+	//if (tbl_size == 0 || dest == 0)	/* LAN alerting not supported */
+	//	return;
 
 	lsel.id = PEF_LAN_CFGPARM_ID_DESTTYPE;
 	lsel.set = dest;
@@ -311,7 +307,7 @@ ipmi_pef_print_lan_dest(struct ipmi_intf * intf, uint8_t ch, uint8_t dest)
 				"PET community");
 		else {
 			rsp->data[19] = '\0';
-			ipmi_pef_print_str("PET Community", &rsp->data[1]);
+			ipmi_pef_print_str("PET Community", (const char *)&rsp->data[1]);
 		}
 	}
 	ipmi_pef_print_dec("ACK timeout/retry (secs)", timeout);
@@ -690,7 +686,7 @@ ipmi_pef_list_policies(struct ipmi_intf * intf)
 
 			if (ptmp->entry.alert_string_key & PEF_POLICY_EVENT_SPECIFIC) {
 				ipmi_pef_print_str("Event-specific", "true");
-				continue;
+//				continue;
 			}			
 			wrk = ptmp->entry.chan_dest;
 
