@@ -28,10 +28,6 @@
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
  * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * You acknowledge that this software is not designed or intended for use
- * in the design, construction, operation or maintenance of any nuclear
- * facility.
  */
 
 #include <string.h>
@@ -43,6 +39,7 @@
 #include <ipmitool/helper.h>
 #include <ipmitool/ipmi_intf.h>
 #include <ipmitool/ipmi_raw.h>
+#include <ipmitool/ipmi_strings.h>
 
 #define IPMI_I2C_MASTER_MAX_SIZE	0x40
 
@@ -194,6 +191,18 @@ ipmi_rawi2c_main(struct ipmi_intf * intf, int argc, char ** argv)
 			printf(" %2.2x", rsp->data[i]);
 		}
 		printf("\n");
+
+		if (rsp->data_len <= 4) {
+			uint32_t bit;
+			int j;
+			for (i = 0; i < rsp->data_len; i++) {
+				for (j = 1, bit = 0x80; bit > 0; bit /= 2, j++) {
+					printf("%s", (rsp->data[i] & bit) ? "1" : "0");
+				}
+				printf(" ");
+			}
+			printf("\n");
+		}
 	}
 
 	return 0;
@@ -204,13 +213,14 @@ ipmi_raw_main(struct ipmi_intf * intf, int argc, char ** argv)
 {
 	struct ipmi_rs * rsp;
 	struct ipmi_rq req;
-	uint8_t netfn, cmd;
+	uint8_t netfn, cmd, lun;
 	int i;
-
 	uint8_t data[256];
 
 	if (argc < 2 || strncmp(argv[0], "help", 4) == 0) {
 		lprintf(LOG_NOTICE, "RAW Commands:  raw <netfn> <cmd> [data]");
+		print_valstr(ipmi_netfn_vals, "Network Function Codes", LOG_NOTICE);
+		lprintf(LOG_NOTICE, "(can also use raw hex values)");
 		return -1;
 	}
 	else if (argc > sizeof(data))
@@ -219,12 +229,21 @@ ipmi_raw_main(struct ipmi_intf * intf, int argc, char ** argv)
 		return -1;
 	}
 
-	netfn = (uint8_t)strtol(argv[0], NULL, 0);
+	ipmi_intf_session_set_timeout(intf, 15);
+	ipmi_intf_session_set_retry(intf, 1);
+
+	lun = intf->target_lun;
+	netfn = str2val(argv[0], ipmi_netfn_vals);
+	if (netfn == 0xff) {
+		netfn = (uint8_t)strtol(argv[0], NULL, 0);
+	}
+
 	cmd = (uint8_t)strtol(argv[1], NULL, 0);
 
 	memset(data, 0, sizeof(data));
 	memset(&req, 0, sizeof(req));
 	req.msg.netfn = netfn;
+	req.msg.lun = lun;	
 	req.msg.cmd = cmd;
 	req.msg.data = data;
 
@@ -234,8 +253,10 @@ ipmi_raw_main(struct ipmi_intf * intf, int argc, char ** argv)
 		req.msg.data_len++;
 	}
 
-	lprintf(LOG_INFO, "RAW REQ (netfn=0x%x cmd=0x%x data_len=%d)",
-		req.msg.netfn, req.msg.cmd, req.msg.data_len);
+	lprintf(LOG_INFO, 
+           "RAW REQ (channel=0x%x netfn=0x%x lun=0x%x cmd=0x%x data_len=%d)",
+           intf->target_channel & 0x0f, req.msg.netfn,req.msg.lun , 
+           req.msg.cmd, req.msg.data_len);
 
 	printbuf(req.msg.data, req.msg.data_len, "RAW REQUEST");
 
@@ -243,14 +264,14 @@ ipmi_raw_main(struct ipmi_intf * intf, int argc, char ** argv)
 
 	if (rsp == NULL) {
 		lprintf(LOG_ERR, "Unable to send RAW command "
-			"(netfn=0x%x cmd=0x%x)",
-			req.msg.netfn, req.msg.cmd);
+			"(channel=0x%x netfn=0x%x lun=0x%x cmd=0x%x)",
+			intf->target_channel & 0x0f, req.msg.netfn, req.msg.lun, req.msg.cmd);
 		return -1;
 	}
 	if (rsp->ccode > 0) {
 		lprintf(LOG_ERR, "Unable to send RAW command "
-			"(netfn=0x%x cmd=0x%x rsp=0x%x): %s",
-			req.msg.netfn, req.msg.cmd, rsp->ccode,
+			"(channel=0x%x netfn=0x%x lun=0x%x cmd=0x%x rsp=0x%x): %s",
+			intf->target_channel & 0x0f, req.msg.netfn, req.msg.lun, req.msg.cmd, rsp->ccode,
 			val2str(rsp->ccode, completion_code_vals));
 		return -1;
 	}
