@@ -42,13 +42,15 @@
 #include <signal.h>
 #include <unistd.h>
 
-#include <config.h>
+#if defined(HAVE_CONFIG_H)
+# include <config.h>
+#endif
 
 #if defined(HAVE_TERMIOS_H)
 # include <termios.h>
 #elif defined (HAVE_SYS_TERMIOS_H)
 # include <sys/termios.h>
-#endif        
+#endif
 
 #include <ipmitool/helper.h>
 #include <ipmitool/log.h>
@@ -1206,7 +1208,7 @@ processSolUserInput(
 				continue;
 
 			case 'B':
-				printf("%cb [send break]\r\n",
+				printf("%cB [send break]\r\n",
 				       intf->session->sol_escape_char);
 				sendBreak(intf);
 				continue;
