@@ -28,17 +28,36 @@
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
  * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * You acknowledge that this software is not designed or intended for use
- * in the design, construction, operation or maintenance of any nuclear
- * facility.
  */
 
 #include <stddef.h>
 #include <ipmitool/ipmi_strings.h>
 #include <ipmitool/ipmi_constants.h>
 #include <ipmitool/ipmi_sensor.h>
+#include <ipmitool/ipmi_sel.h>  /* for IPMI_OEM */
 
+const struct valstr ipmi_oem_info[] = {
+
+   { IPMI_OEM_UNKNOWN,    "Unknown" },
+   { IPMI_OEM_SUN,        "Sun Microsystems" },
+   { IPMI_OEM_INTEL,      "Intel Corporation" },
+   { IPMI_OEM_TYAN,       "Tyan Computer Corporation" },
+   { IPMI_OEM_NEWISYS,    "Newisys" },
+   { IPMI_OEM_SUPERMICRO, "Supermicro" },
+   { IPMI_OEM_KONTRON,    "Kontron" },
+   { 0xffff , NULL },
+};
+
+const struct valstr ipmi_netfn_vals[] = {
+	{ IPMI_NETFN_CHASSIS,	"Chassis" },
+	{ IPMI_NETFN_BRIDGE,	"Bridge" },
+	{ IPMI_NETFN_SE,	"SensorEvent" },
+	{ IPMI_NETFN_APP,	"Application" },
+	{ IPMI_NETFN_FIRMWARE,	"Firmware" },
+	{ IPMI_NETFN_STORAGE,	"Storage" },
+	{ IPMI_NETFN_TRANSPORT,	"Transport" },
+	{ 0xff,			NULL },
+};
 
 /*
  * From table 26-4 of the IPMI v2 specification
@@ -142,6 +161,18 @@ const struct valstr entity_id_vals[] = {
 	{ 0x26, "Remote Management Device" },
 	{ 0x27, "External Environment" },
 	{ 0x28, "Battery" },
+    { 0x29, "Processing Blade" },
+    { 0x2A, "Connectivity Switch" },
+    { 0x2B, "Processor/Memory Module" },
+    { 0x2C, "I/O Module" },
+    { 0x2D, "Processor/IO Module" },
+    { 0x2E, "Management Controller Firmware" },
+    { 0x2F, "IPMI Channel" },
+    { 0x30, "PCI Bus" },
+    { 0x31, "PCI Express Bus" },
+    { 0x32, "SCSI Bus (parallel)" },
+    { 0x33, "SATA/SAS Bus" },
+    { 0x34, "Processor/Front-Side Bus" },
 	{ 0x00, NULL },
 };
 
