@@ -42,7 +42,9 @@
 #include <sys/stat.h>
 #include <signal.h>
 
-#include <config.h>
+#if defined(HAVE_CONFIG_H)
+# include <config.h>
+#endif
 
 #ifdef HAVE_PATHS_H
 # include <paths.h>
@@ -638,6 +640,16 @@ ipmievd_main(struct ipmi_event_intf * eintf, int argc, char ** argv)
 		}
 	}
 
+	/*
+	 * We need to open interface before forking daemon
+	 * so error messages are not lost to syslog and
+	 * return code is successfully returned to initscript
+	 */
+	if (eintf->intf->open(eintf->intf) < 0) {
+		lprintf(LOG_ERR, "Unable to open interface");
+		return -1;
+	}
+
 	if (daemon) {
 		FILE *fp;
 		struct stat st1;
