@@ -28,10 +28,6 @@
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
  * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE,
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * You acknowledge that this software is not designed or intended for use
- * in the design, construction, operation or maintenance of any nuclear
- * facility.
  */
 
 #include <stdio.h>
@@ -52,8 +48,8 @@
 # include <config.h>
 #endif
 
-#define EXEC_BUF_SIZE	1024
-#define EXEC_ARG_SIZE	32
+#define EXEC_BUF_SIZE	2048
+#define EXEC_ARG_SIZE	64
 
 extern const struct valstr ipmi_privlvl_vals[];
 extern const struct valstr ipmi_authtype_session_vals[];
@@ -96,7 +92,7 @@ static int rl_event_keepalive(void)
 
 int ipmi_shell_main(struct ipmi_intf * intf, int argc, char ** argv)
 {
-	char *ptr, *pbuf, **ap, *__argv[20];
+	char *ptr, *pbuf, **ap, *__argv[EXEC_ARG_SIZE];
 	int __argc, rc=0;
 
 	rl_readline_name = "ipmitool";
@@ -111,8 +107,9 @@ int ipmi_shell_main(struct ipmi_intf * intf, int argc, char ** argv)
 		shell_intf = intf;
 		rl_event_hook = rl_event_keepalive;
 #if defined(RL_READLINE_VERSION) && RL_READLINE_VERSION >= 0x0402
-		/* set to 1 second */
-		rl_set_keyboard_input_timeout(1000*1000);
+		/* There is a bug in readline 4.2 and later (at least on FreeBSD):
+		 * timeout equal or greater than 1 second causes an infinite loop. */
+		rl_set_keyboard_input_timeout(1000 * 1000 - 1);
 #endif
 	}
 
@@ -187,7 +184,7 @@ int ipmi_shell_main(struct ipmi_intf * intf, int argc, char ** argv)
 			}
 
 			if (**ap != '\0') {
-				if (++ap >= &__argv[20])
+				if (++ap >= &__argv[EXEC_ARG_SIZE])
 					break;
 			}
 		}
@@ -214,6 +211,16 @@ ipmi_shell_main(struct ipmi_intf * intf, int argc, char ** argv)
 
 #endif /* HAVE_READLINE */
 
+void ipmi_echo_main(struct ipmi_intf * intf, int argc, char ** argv)
+{
+	int i;
+
+	for (i=0; i<argc; i++) {
+		printf("%s ", argv[i]);
+	}
+	printf("\n");
+}
+
 static void
 ipmi_set_usage(void)
 {
